/// <reference types="react" />
import * as react from 'react';
import react__default, { PropsWithChildren, ComponentProps } from 'react';
import * as _tanstack_react_query from '@tanstack/react-query';
import { QueryClient } from '@tanstack/react-query';
import * as valibot from 'valibot';
import { Output } from 'valibot';
import * as _backstage_core_plugin_api from '@backstage/core-plugin-api';

type CoderAuthProviderProps = Readonly<PropsWithChildren<unknown>>;
declare const CoderAuthProvider: ({ children }: CoderAuthProviderProps) => react__default.JSX.Element;

declare const yamlConfigSchema: valibot.UnionSchema<(valibot.UndefinedSchema<undefined> | valibot.ObjectSchema<{
    templateName: valibot.OptionalSchema<valibot.StringSchema<string>, undefined, string | undefined>;
    mode: valibot.OptionalSchema<valibot.UnionSchema<(valibot.LiteralSchema<"manual", "manual"> | valibot.LiteralSchema<"auto", "auto">)[], "manual" | "auto">, undefined, "manual" | "auto" | undefined>;
    params: valibot.OptionalSchema<valibot.RecordSchema<valibot.StringSchema<string>, valibot.UnionSchema<(valibot.StringSchema<string> | valibot.UndefinedSchema<undefined>)[], string | undefined>, {
        [x: string]: string | undefined;
    }>, undefined, {
        [x: string]: string | undefined;
    } | undefined>;
}, undefined, {
    templateName?: string | undefined;
    mode?: "manual" | "auto" | undefined;
    params?: {
        [x: string]: string | undefined;
    } | undefined;
}>)[], {
    templateName?: string | undefined;
    mode?: "manual" | "auto" | undefined;
    params?: {
        [x: string]: string | undefined;
    } | undefined;
} | undefined>;
type YamlConfig = Output<typeof yamlConfigSchema>;
type CoderEntityConfig = Readonly<{
    [Key in keyof CoderWorkspaceConfig]-?: Readonly<CoderWorkspaceConfig[Key]>;
} & {
    repoUrl: string | undefined;
}>;
declare function useCoderEntityConfig(): CoderEntityConfig;

type CoderWorkspaceConfig = Readonly<Exclude<YamlConfig, undefined> & {
    templateName: string;
    repoUrlParamKeys: readonly [string, ...string[]];
}>;
type CoderDeploymentConfig = Readonly<{
    accessUrl: string;
}>;
type CoderAppConfig = Readonly<{
    workspaces: CoderWorkspaceConfig;
    deployment: CoderDeploymentConfig;
}>;
type CoderSettingsProviderProps = Readonly<PropsWithChildren<{
    appConfig: CoderAppConfig;
}>>;
declare const CoderAppConfigProvider: ({ children, appConfig, }: CoderSettingsProviderProps) => react__default.JSX.Element;

type CoderProviderProps = ComponentProps<typeof CoderAuthProvider> & ComponentProps<typeof CoderAppConfigProvider> & {
    queryClient?: QueryClient;
};

type UseCoderWorkspacesOptions = Readonly<Partial<{
    repoConfig: CoderEntityConfig;
}>>;
declare function useCoderWorkspaces(coderQuery: string, options?: UseCoderWorkspacesOptions): _tanstack_react_query.UseQueryResult<readonly {
    id: string;
    name: string;
    template_icon: string;
    owner_name: string;
    latest_build: {
        id: string;
        status: "canceled" | "canceling" | "deleted" | "deleting" | "failed" | "pending" | "running" | "starting" | "stopped" | "stopping";
        resources: {
            id: string;
            agents?: {
                id: string;
                status: "connected" | "connecting" | "disconnected" | "timeout";
            }[] | undefined;
        }[];
    };
}[], unknown>;

declare const coderPlugin: _backstage_core_plugin_api.BackstagePlugin<{
    root: _backstage_core_plugin_api.RouteRef<undefined>;
}, {}, {}>;
/**
 * All public component exports exposed by the plugin.
 */
declare const CoderProvider: ({ children, appConfig, queryClient, }: CoderProviderProps) => react.JSX.Element;
declare const CoderAuthWrapper: ({ children, type }: Readonly<react.PropsWithChildren<{
    type: "card";
}>>) => react.JSX.Element;
declare const CoderErrorBoundary: ({ children, fallbackUi, }: {
    children?: react.ReactNode;
    fallbackUi?: react.ReactNode;
}) => react.JSX.Element;
declare const CoderWorkspacesCard: (props: Omit<Readonly<Omit<react.HTMLAttributes<HTMLDivElement>, "role" | "aria-labelledby"> & {
    queryFilter?: string | undefined;
    defaultQueryFilter?: string | undefined;
    onFilterChange?: ((newFilter: string) => void) | undefined;
    readEntityData?: boolean | undefined;
}>, "children">) => react.JSX.Element;

export { CoderAppConfig, CoderAuthWrapper, CoderErrorBoundary, CoderProvider, CoderWorkspacesCard, coderPlugin, useCoderEntityConfig, useCoderWorkspaces };
